@@ -1,3 +1,11 @@
+"""
+Provides the base classes for ORM models' declaring, including corresponding
+metaclass (used by the SQLAlchemy declarative definition), the base Model
+class (used by ALL ORM models of the project) and the Model.Meta class,
+describing additional models' properties and providing some extra
+functionality for the models' handling.
+"""
+
 import datetime
 import decimal
 import inspect
@@ -17,7 +25,6 @@ from sqlalchemy.sql import Select, Delete, sqltypes
 from sqlalchemy.sql.elements import ClauseList, BinaryExpression, UnaryExpression
 
 from . import reg
-from .types import Attribute
 from ... import config, logger
 from ...runtime import context
 from ...tools import CSTYLE, snakecase_to_lowercamelcase, app_name
@@ -31,6 +38,10 @@ __all__ = [
 
 
 class _ModelMetaclass(DeclarativeMeta):
+    """
+    The metaclass used by the SQLAlchemy declarative base.
+    """
+
     def __init__(cls, name, bases, clsdict):
         tablename: Optional[str] = None
 
@@ -51,17 +62,18 @@ class _ModelMetaclass(DeclarativeMeta):
         if not app:
             return
 
+        # Handling the ``Meta`` creation of the ORM model
         meta: Meta = Meta(cls, app, cls.__module__)
+
         for key, attr in cls.__dict__.items():
+            # Handle the auto-assigning of the ``Caption``-based column as
+            # the model's caption attribute.
             if isinstance(attr, Column):
                 meta.columns.append(attr)
 
-            if isinstance(attr, Attribute):
-                meta.attributes.append(attr)
-                attr.parent_class = cls
-                attr.parent_key = key
-
         cls.Meta = meta
+
+        # Handle the model registration
         if app not in reg.app_models:
             reg.app_models[app] = dict()
         reg.app_models[app][cls.__decl_cls_name__] = cls
@@ -129,6 +141,8 @@ class Model:
     """
 
     Meta: 'Meta'
+    """ This model's subclass describing some optionals and service methods for the ORM class. 
+    For more details see :class:`~wefram.ds.Meta` class."""
 
     @property
     def __caption__(self) -> str:
@@ -849,11 +863,31 @@ DatabaseModel = declarative_base(cls=Model, metaclass=_ModelMetaclass)
 
 @dataclass
 class History:
+    """
+    History Meta used in conjuction with model's ``Meta`` class to declare the
+    model's instances' journaling.
+    """
+
     enable: bool = False
+    """ If set to ``True`` - Wefram will log actions on the given model. Creating,
+    modifition and deletion actions will be logged to the corresponding journaling
+    table. """
+
     model: ClassVar = None
+    """ The corresponding model class for the logging. """
+
     ignore: List[Union[str, Column]] = None
+    """ The optional list of excluded from the monitoring attributes. Changes of
+    given attributes will not trigger the history record creation. """
+
     attributes: List[Union[str, Column]] = None
+    """ The optional list of attributes whose to include in the history record
+    state. If is omitted - all columns will be taken. """
+
     exclude: List[Union[str, Column]] = None
+    """ The optional list of attributes whose about to be excluded from the
+    history record state. Those attributes, even if been changed, will not been
+    recorded to the history state dump. """
 
 
 class Meta:
@@ -972,7 +1006,7 @@ class Meta:
     """
 
     history: History
-    """ (history) """
+    """ The history defition, describing journaling of instances of this model. """
 
     def __init__(self, cls: _ModelMetaclass, app_name: str, module_name: str):
         self.model: ClassVar = cls
