@@ -1,4 +1,4 @@
-export * from '../types/aaa'
+export * from './types'
 export * from './api'
 export * from './provider'
-export * from './session'
\ No newline at end of file
+export * from './session'
