@@ -1,5 +1,5 @@
 import {observable, computed, makeObservable, toJS} from 'mobx'
-import {SessionUser, Permissions} from '../types/aaa'
+import {SessionUser, Permissions} from './types'
 
 
 class Session {
@@ -48,11 +48,4 @@ class Session {
   }
 }
 
-export type ClientSession = {
-  user: SessionUser | null
-  permissions: Permissions
-}
-
-export type ClientSessionResponse = ClientSession | null
-
 export const session = new Session()
