@@ -13,7 +13,7 @@ import {storage} from 'system/storage'
 import {RequestApiPath, routing} from 'system/routing'
 import {api} from 'system/api'
 import {notifications} from 'system/notification'
-import {runtime} from 'system/runtime'
+import {runtime} from 'system/project'
 import {gettext} from 'system/l10n'
 import {dialog} from 'system/dialog'
 import './index.css'
