@@ -8,8 +8,7 @@ export * from './DateTimes'
 export * from './DialogWindowTitle'
 export * from './DigitsInputField'
 export * from './DividerRuler'
-export * from './EntityList'
-export * from './EntityTable'
+export * from './EntityEnums'
 export * from './FetchFailedBox'
 export * from './Forms'
 export * from './FormCommonField'
@@ -31,7 +30,7 @@ export * from './OptionsList'
 export * from './PasswordSetter'
 export * from './RelIcon'
 export * from './Ruler'
-export * from './Lists'
+export * from './ProvEnums'
 export * from './Spacing'
 export * from './StaticText'
 export * from './StoredFilesList'
