@@ -1,12 +1,12 @@
 import React from 'react'
-import {ScreenProps} from 'system/types'
+import {ScreenProps} from 'system/screens'
 import {
   Box,
   Paper,
   StoredFilesList,
   Typography
 } from 'system/components'
-import {runtime} from 'system/runtime'
+import {runtime} from 'system/project'
 
 
 type ScreenState = {
