@@ -1,3 +1,7 @@
+"""
+Provides common localization functions used by applications in the code.
+"""
+
 from typing import *
 import babel
 import babel.numbers
@@ -20,6 +24,8 @@ __all__ = [
 
 
 def current_locale() -> Locale:
+    """ Returns the current locale for the current (request-level) user. """
+
     if 'locale' not in context:
         raise RuntimeError(EXC_CONTEXT)
     return context['locale']
@@ -27,7 +33,7 @@ def current_locale() -> Locale:
 
 def best_matching_locale(options: List[str]) -> Optional[babel.Locale]:
     """ Returns a best matched locale name for given options list. If there is no any matchings -
-    returns None.
+    returns ``None``.
     """
     for option in options:
         try:
@@ -53,10 +59,24 @@ def lazy_gettext(
 
 def lazy_ngettext(
         num: [int, float, callable],
-        untranslated: str,
+        singular_untranslated: str,
+        plural_untranslated: str,
         domain: Optional[str] = None
 ) -> L10nStr:
-    return L10nStr(untranslated, domain, num)
+    """ The same as :func:`~wefram.l10n.lazy_gettext` function, used to translate the
+    numeric variant. The function expects the number for which the corresponding
+    selection must be choosen (based on that number the singular or plural form will
+    be choosed), and two forms: the singular one and the plural one. For example:
+
+    `` lazy_ngettext(my_module.my_func, "User", "Users") ``
+
+    """
+    return L10nStr(
+        untranslated=singular_untranslated,
+        domain=domain,
+        plural_num=num,
+        plural_untranslated=plural_untranslated
+    )
 
 
 def gettext(
@@ -72,14 +92,20 @@ def gettext(
 
 def ngettext(
         num: [int, float, callable],
-        untranslated: str,
+        singular_untranslated: str,
+        plural_untranslated: str,
         domain: Optional[str] = None
 ) -> str:
-    """ Translates the given untranslated message at a time this function being called. This
-    means that there must be a running valid request context to make translation succeed.
+    """ The same as :func:`~wefram.l10n.gettext` function, used to translate the
+    numeric variant. The function expects the number for which the corresponding
+    selection must be choosen (based on that number the singular or plural form will
+    be choosed), and two forms: the singular one and the plural one. For example:
+
+    `` ngettext(my_module.my_func, "User", "Users") ``
+
     """
     app_name: str = get_calling_app()
-    return translate_pluralizable(num, untranslated, domain, app_name)
+    return translate_pluralizable(num, [singular_untranslated, plural_untranslated], domain, app_name)
 
 
 def format_decimal(number: [int, float], locale_: Optional[Locale] = None) -> str:
