@@ -60,8 +60,8 @@ async def run(targets: list) -> None:
 
     # The list of project roots whose about to make
     roots: List[str] = []
-    if config.ASSETS_DIR:
-        roots.append(config.ASSETS_DIR)
+    if config.ASSETS_SRC_DIR:
+        roots.append(config.ASSETS_SRC_DIR)
 
     # Defining the global build context which may be used by apps
     ctx: dict = dict()
@@ -119,11 +119,16 @@ async def run(targets: list) -> None:
                 f"Cannot find facility serves the make target '{target}'!"
             ) from exc
 
-        makefunc: callable = getattr(target_module, 'run')
-        if asyncio.iscoroutinefunction(makefunc):
-            await makefunc(roots)
-        else:
-            makefunc(roots)
+        try:
+            makefunc: callable = getattr(target_module, 'run')
+            if asyncio.iscoroutinefunction(makefunc):
+                await makefunc(roots)
+            else:
+                makefunc(roots)
+        except RuntimeError:
+            print(f"\n\nMake {CSTYLE['red']}FAILED{CSTYLE['clear']}, please read the messages above")
+            exit(1)
+            break
 
     # Storing the timestamp when the make done
     end_timestamp = datetime.now()
