@@ -94,14 +94,14 @@ class MailAccountsScreen(ui.screens.Screen):
     order = 50
 
 
-@ui.screens.register(sitemap=SITEMAP_FOLDER_ID)
-class TestScreen(ui.screens.EntityScreen):
-    entity = 'MailAccount'
-    route = '/test'
-    parent = APP_ID
-    icon = None
-    requires = mail.PERMISSION
-    caption = "Testing"
-    order = 60
+# @ui.screens.register(sitemap=SITEMAP_FOLDER_ID)
+# class TestScreen(ui.screens.EntityScreen):
+#     entity = 'MailAccount'
+#     route = '/test'
+#     parent = APP_ID
+#     icon = None
+#     requires = mail.PERMISSION
+#     caption = "Testing"
+#     order = 60
 
 
